@@ -1,6 +1,6 @@
 context("Downloading FinBIF records")
 
-vcr::use_cassette(
+use_cassette(
   "finbif_records", {
 
     test_that(
@@ -49,6 +49,11 @@ vcr::use_cassette(
           "finbif_api"
         )
 
+        expect_s3_class(
+          finbif_records(aggregate = "records", count_only = TRUE),
+          "finbif_api"
+        )
+
       }
     )
 
@@ -59,7 +64,9 @@ vcr::use_cassette(
 test_that(
   "returns errors appropriately", {
 
-    expect_condition(finbif_records(n = 1e99))
+    expect_condition(finbif_records(n = 0))
+
+    expect_condition(finbif_records(n = 1e9))
 
     expect_condition(finbif_records(filter = c(not_a_filter = TRUE)))
 
